@@ -1,16 +1,17 @@
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 
 from odoorpc.tests import LoginTestCase
 
 
 class TestFieldInteger(LoginTestCase):
-
     def test_field_integer_read(self):
         self.assertIsInstance(self.user.id, int)
 
     def test_field_integer_write(self):
         cron_obj = self.odoo.env['ir.cron']
-        cron = cron_obj.browse(cron_obj.search([])[0])
+        cron = cron_obj.browse(
+            cron_obj.with_context(active_test=False).search([])[0]
+        )
         backup = cron.priority
         # False
         cron.priority = False
@@ -37,5 +38,3 @@ class TestFieldInteger(LoginTestCase):
         data = cron.read(['priority'])[0]
         self.assertEqual(data['priority'], backup)
         self.assertEqual(cron.priority, backup)
-
-# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
