@@ -8,24 +8,20 @@ from odoorpc.tools import v
 
 class TestReport(LoginTestCase):
     def test_report_download_pdf(self):
-        model = 'res.company'
         report_name = 'web.preview_internalreport'
+        model = 'res.company'
         if v(self.odoo.version)[0] < 11:
             report_name = 'preview.report'
         ids = self.odoo.env[model].search([])[:20]
-        report = self.odoo.report.download(report_name, ids)
-        with tempfile.TemporaryFile(mode='wb', suffix='.pdf') as file_:
-            file_.write(report.read())
-
-    def test_report_download_qweb_pdf(self):
-        model = 'account.move'
-        if v(self.odoo.version)[0] < 13:
-            model = 'account.invoice'
-        report_name = 'account.report_invoice'
-        ids = self.odoo.env[model].search([])[:10]
-        report = self.odoo.report.download(report_name, ids)
-        with tempfile.TemporaryFile(mode='wb', suffix='.pdf') as file_:
-            file_.write(report.read())
+        try:
+            report = self.odoo.report.download(report_name, ids)
+            with tempfile.TemporaryFile(mode='wb', suffix='.pdf') as file_:
+                file_.write(report.read())
+        except NotImplementedError:
+            self.skipTest(
+                "Report downloading is not supported in version %s"
+                % (self.odoo.version)
+            )
 
     def test_report_download_wrong_report_name(self):
         self.assertRaises(
